MockProjectBuilderExt

Trait MockProjectBuilderExt 

pub trait MockProjectBuilderExt {
    // Required methods
    fn project_compiler<Ext>(
        &self,
    ) -> FileResult<(MockProjectCompiler<Ext>, UnboundedReceiver<NotifyMessage>)>
       where Ext: Default + 'static;
    fn project_compiler_with_opts<Ext>(
        &self,
        opts: CompileServerOpts<MockCompilerFeat, Ext>,
    ) -> FileResult<(MockProjectCompiler<Ext>, UnboundedReceiver<NotifyMessage>)>
       where Ext: Default + 'static;
}
Extension helpers for building project compilers from mock world builders.

Required Methods

fn project_compiler<Ext>( &self, ) -> FileResult<(MockProjectCompiler<Ext>, UnboundedReceiver<NotifyMessage>)>
where Ext: Default + 'static,

Builds a syntax-only project compiler and its notify receiver.

fn project_compiler_with_opts<Ext>( &self, opts: CompileServerOpts<MockCompilerFeat, Ext>, ) -> FileResult<(MockProjectCompiler<Ext>, UnboundedReceiver<NotifyMessage>)>
where Ext: Default + 'static,

Builds a project compiler with custom options and its notify receiver.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl MockProjectBuilderExt for MockWorldBuilder

Source

fn project_compiler<Ext>( &self, ) -> FileResult<(MockProjectCompiler<Ext>, UnboundedReceiver<NotifyMessage>)>
where Ext: Default + 'static,

Source

fn project_compiler_with_opts<Ext>( &self, opts: CompileServerOpts<MockCompilerFeat, Ext>, ) -> FileResult<(MockProjectCompiler<Ext>, UnboundedReceiver<NotifyMessage>)>
where Ext: Default + 'static,

Implementors