MockProjectChangeExt

Trait MockProjectChangeExt 

pub trait MockProjectChangeExt {
    // Required methods
    fn apply_as_fs_to_project<F, Ext>(
        &self,
        compiler: &mut ProjectCompiler<F, Ext>,
        is_sync: bool,
    )
       where F: CompilerFeat + Send + Sync + 'static,
             Ext: Default + 'static;
    fn apply_as_memory_to_project<F, Ext>(
        &self,
        compiler: &mut ProjectCompiler<F, Ext>,
    )
       where F: CompilerFeat + Send + Sync + 'static,
             Ext: Default + 'static;
}
Applies VFS mock changes to project compilers.

Required Methods

fn apply_as_fs_to_project<F, Ext>( &self, compiler: &mut ProjectCompiler<F, Ext>, is_sync: bool, )
where F: CompilerFeat + Send + Sync + 'static, Ext: Default + 'static,

Applies this change to a project compiler as a filesystem event.

fn apply_as_memory_to_project<F, Ext>( &self, compiler: &mut ProjectCompiler<F, Ext>, )
where F: CompilerFeat + Send + Sync + 'static, Ext: Default + 'static,

Applies this change to a project compiler as a memory event.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl MockProjectChangeExt for MockChange

Source

fn apply_as_fs_to_project<F, Ext>( &self, compiler: &mut ProjectCompiler<F, Ext>, is_sync: bool, )
where F: CompilerFeat + Send + Sync + 'static, Ext: Default + 'static,

Source

fn apply_as_memory_to_project<F, Ext>( &self, compiler: &mut ProjectCompiler<F, Ext>, )
where F: CompilerFeat + Send + Sync + 'static, Ext: Default + 'static,

Implementors